<?php

declare(strict_types=1);

namespace Cin\Quickcategory5;

use JTL\Catalog\Category\Kategorie;
use JTL\Catalog\Category\KategorieListe;

final class CategoryService
{
  public static function getCategories(int $root, string $sortMode): array
  {
    $categories = new KategorieListe();

    $categories = $categories->getChildCategories((int) $root, 0, 0);

    switch ($sortMode) {
      case 'ascendingByName':
        usort($categories, static fn (Kategorie $a, Kategorie $b) => strcmp($a->getName(), $b->getName()));

        break;
      case 'descendingByName':
        usort($categories, static fn (Kategorie $a, Kategorie $b) => strcmp($a->getName(), $b->getName()));
        $categories = array_reverse($categories);

        break;
      case 'descendingByWawi':
        $categories = array_reverse($categories);

        break;
    }

    return $categories;
  }

  /**
   * Find the level to beginning with category selection.
   *
   * @param int           $rootID         root ID for beginning of category selections
   * @param null|string[] &$categoryNames List of presetted category names
   *
   * @return int field level for legacy view. On value 0 no match found.
   */
  public static function legacyLevel(int $rootID, Kategorie $category, ?array &$categoryNames): int
  {
    $step          = 1;
    $categoryNames = [];

    // $category = new Kategorie($_SESSION['LetzteKategorie']);
    array_unshift($categoryNames, $category->getName());

    if ($rootID === $category->getID()) {
      return $step;
    }

    while ($category->istUnterkategorie()) {
      ++$step;

      if ($rootID === $category->getParentID()) {
        return $step;
      }

      $category = new Kategorie($category->getParentID());
      array_unshift($categoryNames, $category->getName());
    }

    return 1;
  }
}
